package com.vctgo.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.vctgo.system.api.domain.dto.ReLocationDto;
import com.vctgo.system.api.domain.SysReLocationClass;

import java.util.List;

/**
 * 位置与班级关联Service接口
 *
 * @author caesar
 * @date 2023-05-30
 */
public interface ISysReLocationClassService extends IService<SysReLocationClass>
{
    /**
     * 查询位置与班级关联
     *
     * @param id 位置与班级关联主键
     * @return 位置与班级关联
     */
    SysReLocationClass selectSysReLocationClassById(Long id);

    /**
     * 查询位置与班级关联列表-分页
     *
     * @param sysReLocationClass 位置与班级关联
     * @return 位置与班级关联集合
     */
    IPage<SysReLocationClass> selectSysReLocationClassPage(SysReLocationClass sysReLocationClass);

    /**
     * 查询位置与班级关联列表
     *
     * @param sysReLocationClass 位置与班级关联
     * @return 位置与班级关联集合
     */
    List<SysReLocationClass> selectSysReLocationClassList(SysReLocationClass sysReLocationClass);

    /**
     * 查询位置相关信息列表
     *
     * @param reLocationDto 位置相关信息
     * @return 位置相关信息集合
     */
    List<ReLocationDto> selectLocationInfoByParam(ReLocationDto reLocationDto);

    /**
     * 通过班级id统计绑定的位置总数
     *
     * @param classId 班级id
     * @return 班级配置人员总数
     */
    Long staticsReLocationByClassId(Long classId);

    /**
     * 新增位置与班级关联
     *
     * @param sysReLocationClass 位置与班级关联
     * @return 结果
     */
    int insertSysReLocationClass(SysReLocationClass sysReLocationClass);

    /**
     * 修改位置与班级关联
     *
     * @param sysReLocationClass 位置与班级关联
     * @return 结果
     */
    int updateSysReLocationClass(SysReLocationClass sysReLocationClass);

    /**
     * 批量删除位置与班级关联
     *
     * @param ids 需要删除的位置与班级关联主键集合
     * @return 结果
     */
    int deleteSysReLocationClassByIds(Long[] ids);

    /**
     * 删除位置与班级关联信息
     *
     * @param id 位置与班级关联主键
     * @return 结果
     */
    int deleteSysReLocationClassById(Long id);

    /**
     * 通过位置Id和班级Id批量删除
     *
     * @param locationId 位置id
     * @param areaIds    需要删除的数据主键集合
     * @return
     */
    int updateSysReLocationClassBylocationIdAndAreaIds(Long locationId, Long[] areaIds);
}
